#
# spec file for package cantarell-fonts
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cantarell-fonts
Version:        0.303.1
Release:        1.4
Summary:        Contemporary Humanist Sans Serif Font
License:        OFL-1.1
Group:          System/X11/Fonts
URL:            https://wiki.gnome.org/Projects/CantarellFonts
Source0:        https://download.gnome.org/sources/cantarell-fonts/0.303/%{name}-%{version}.tar.xz

# needed for directory ownership
BuildRequires:  fontconfig
BuildRequires:  fontpackages-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(appstream-glib)
BuildArch:      noarch
%reconfigure_fonts_prereq

%description
The Cantarell font family is a contemporary Humanist sans serif designed
for on-screen reading.

%prep
%autosetup

%build
%meson \
	-Dfontsdir=%{_ttfontsdir} \
	-Duseprebuilt=true \
	%{nil}
%meson_build

%install
%meson_install

%reconfigure_fonts_scriptlets

%files
%license COPYING
%doc NEWS README.md
%dir %{_ttfontsdir}
%{_ttfontsdir}/Cantarell-VF.otf
%{_datadir}/metainfo/org.gnome.cantarell.metainfo.xml

%changelog
* Fri Dec 10 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.303.1:
  + Add missing font.
- Changes from version 0.303:
  + Actually update the version number in the fonts.
- Changes from version 0.302:
  + Maintenance release: Make the variable font the default, only
    build statics on demand. Also build two packages with variable
    and static fonts. Packagers can chose the statics package if
    they run into problems with the variable font, but you should
    probably not install both at the same time.
  + Amended OS/2 super- and subscript values so that new Pango can
    use them properly.
  + Update production names for Jacute, bulletoperator,
    commercialMinusSign, divisionslash, notidentical,
    ringcomb_acutecomb and ringcomb_acutecomb.case.
  + Updated appstream translations.
* Wed Dec 23 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.301:
  + Oopsie-release: The last one was missing PostScript names for
    the new glyphs. Only relevant for when extracting text from
    PDFs where the generator omitted the text stream.
  + Rounded coordinates of macronbelowcomb.narrow and
    macroncomb.narrow.case. Leftovers from when they were scaled
    components.
  + Internal: Removed stale layers and data, added normalization
    script to prune unnecessary data. import-glyphs.py also imports
    PostScript names now.
* Tue Dec 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.300:
  + Import Greek glyph set designed by Florian Fecher for GSoC
    2018. No kerning, might need a slight respacing. Imported
    anyway because someting is better than nothing.
  + Correct positioning of dotaccentcomb.case.
  + Correct mark positioning in caroncomb.case.
  + Correct appearance of ustraightstroke in variable font, the
    overlap became visible at smaller, autohinted sizes.
  + Correct bar positioning in Ustraightstroke and
    ustraightstroke.
  + Correct anchor positioning in Y.
  + Internal: Consolidate various anchors in composites into the
    base outline glyphs, to reduce the chance they get out sync.
  + Updated translations.
* Thu Jan  9 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.201:
  + Oopsie-release: The last one was missing pre-built binaries in
    the release tarball.
  + Use AFDKO's tx to compress the variable font in roughly half.
  + Updated translations.
* Fri Jan  3 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.200:
  + Respacing of uppercase letters in the regular master and
    complete thin and extra bold masters. Uppercase letters space
    better next to lowercase letters now. Cyrillics are more
    consistently spaced.
  + Tweak numerals some. Especially the "one" and fractions.
  + Various tweaks to various shapes across the board, especially
    symbols. Braces are curlier now. Detail tweaks to Cyrillics.
  + Basic mathy symbols and currency symbols now have tabular
    number width. I found no advantage to having proportional
    variants.
  + Removed .tosf numerals. Fiddly work without clear purpose.
  + Experimental alternative form of "l" without the tail.
    Accessible via the ss01 feature.
  + Added variable font, CFF2 flavor. postscriptBlueFuzz is set to
    1 explicitly to avoid rounding issues with blue zone coverage
    in FreeType.
  + Removed f-ligatures without their own Unicode code points, as
    the design doesn't currently need them. They were mainly added
    to fill up the Google glyph set.
  + The following glyphs now represent more than one Unicode code
    point to keep the glyph view tidier:
  - emdash: U+2014, U+2015
  - emspace: U+2001, U+2003
  - enspace: U+2000, U+2002
  - hyphen: U+002D, U+00AD, U+2010, U+2011
  - space: U+0020, U+00A0
  + In PDFs where the generator removed the text stream, copy-paste
    may lead to the others turning into the first.
  + Filled in hryvnia (U+20B4), tugrik (U+20AE) and tenge (U+20B8).
  + Static fonts use same rounding method as varLib uses for the
    variable font.
  + Fixed Ustraight-cy (U+04AE), ustraight-cy (U+04AF),
    Ustraightstroke-cy (U+04B0), ustraightstroke-cy (U+04B1), they
    didn't have a proper production name before and may not have
    been properly accessible.
  + Removed some building components that made it into the final
    font.
  + Limited anchor propagation to letters, excluding ligatures.
    Generate GDEF table properly.
  + Set one simple `gasp` table for hinted display for e.g.
    Windows.
  + Removed `ccmp` from the `aalt` lookup.
  + The OS/2 table fsType now says that no Digital Rights
    Management is applied to the fonts, the name table now says the
    fonts are OFL 1.1 licensed.
  + Internal housekeeping: Sources are stored in the open UFO and
    Designspace format now, with various cleanups like removed
    unused layers.
  + Internal housekeeping: Removed composite diacritics that served
    no design purpose.
- Stop passing -Dconfigdir=%%%%{_fontsconfavaildir} to meson, no
  longer recognized.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 0.111:
  + Fix the wrongly assigned OS/2 weight class values that e.g. led
    to Extra Bold being selected when Bold was requested.
- Changes from version 0.110:
  + Space everything a little bit tighter.
  + Scale down whiteCircle and blackCircle by 50%%, makes password
    dots smaller.
  + Tweak feet of one.lf slightly for a more even appearance.
  + Revise lcaron, dcaron and tcaron for collision-free rendering
    even at bold weight. Will need kerning later.
  + Add draft of Cyrillic (GF Cyrillic Plus set), to be improved.
  + Equalize advance width of period, comma, colon, semicolon.
  + Build packages with prebuilt fonts baked in.
  + New contributed AppStream metadata translations for Slovak.
* Thu Mar 15 2018 luc14n0@linuxmail.org
- Update to version 0.101:
  + Several small improvements.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Feb  9 2018 luc14n0@linuxmail.org
- Update to version 0.100:
  + Redesigned from scratch to interpolate cleanly from thin to
    extra bold. Currently targets the Google Fonts Latin Core and
    Pro glyph sets.
- Update Url tag to https://wiki.gnome.org/Projects/CantarellFonts:
  current Cantarell Fonts' web page.
- Add meson BuildRequires, replace configure/make/make_install
  macros with meson/meson_build/meson_install and remove call for
  gnome-autogen.sh. All of these changes reflect the upstream port
  to Meson build system.
- Drop dos2unix BuildRequires: it's no longer required.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 0.0.25:
  + Outline and spacing on C,G.
  + Improved terminals on numerous glyphs.
  + Weight/stem width fixes (k,G).
  + Port imrpovements from regular to bold.
  + Improved metrics.
  + Fixes to f-ligatures.
  + Shape fixes to some numerals.
  + Fixes to anchors > composited glyphs.
* Tue May  3 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Feb 29 2016 zaitor@opensuse.org
- Update to version 0.0.24:
  + Asymmetric k for bold, fix stem width.
  + Sync bold hyphen metrics with regular.
* Mon Feb 22 2016 zaitor@opensuse.org
- Update to version 0.0.23:
  + Reworked anchors for correct accent rendering under harfbuzz
    1.2.0.
  + More anchor and combined glyph work.
* Mon Feb 15 2016 zaitor@opensuse.org
- Update to version 0.0.22:
  + Improvements to the generation script.
  + Bold: double quotes alignment.
  + Rehint font with adobe toolkit.
* Fri Jan 15 2016 zaitor@opensuse.org
- Update to version 0.0.21:
  + Bold:
  - Latin and cyrillic respace.
  - Adapt f ligatures for the new i.
  - Improvements from Cambay.
  - Match width of numerals to regular.
  + Redular: adjust spacing of Thorn, ß, ẞ.
  + Numerals: improved spacing.
* Thu Jan  7 2016 zaitor@opensuse.org
- Update to version 0.0.20.1:
  + Fix composited glyph issues.
  + Fix parallel build issue.
* Mon Jan  4 2016 zaitor@opensuse.org
- Update to version 0.0.20:
  + Cyrillic improvements.
  + x-height hinting tweaks.
  + Sync bold to regular.
  + OE and oe ligatures.
  + Ratio respaced.
  + Capital sharp s for German.
* Sun Dec 20 2015 damjanovic.ivo@gmail.com
- Update to version 0.0.19:
  + Generate oblique version.
  + More diacritics work; full Latin 4 coverage.
  + Tabular figures.
  + Fold over work done on Cambay.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 0.0.18.1:
  + Improved terminals on a,e,r,s,S,l,2.
  + Fix validation errors.
* Mon Nov  2 2015 zaitor@opensuse.org
- Update to version 0.0.18:
  + Respaced t, 4 and 7.
  + Bold accents fixes.
  + Consistent stem width and various improvements on E, H, B
    and S.
  + Harmonized o and c.
  + Improved capitals.
  + Superscript 123 fixes.
  + Extra glyps for gtk+ (arrows, openbox).
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 0.0.17.2:
  + Rebuild accented glyphs for bold.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 0.0.17.1:
  + Accent fixes.
  + Revert ijbdklh to snap to caps height.
  + Proper weight of f ligatures for bold.
  + Respaced ligatures.
* Sun Oct  4 2015 zaitor@opensuse.org
- Update to version 0.0.17:
  + Improved shapes and metrics:
  - Baseline and bluezone fixes for autohinter to produce valid
    hints.
  - Many glyphs adjusted for baseline and proper hinting.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 0.0.16:
  + Add space variations (bgo#735205).
* Fri Sep 27 2013 zaitor@opensuse.org
- Update to version 0.0.15:
  + Improved spacing for cyrillics (bgo#703588).
  + Fixed hinting on numerals (bgo#704084).
  + Bold outlines improved (bgo#706358).
  + Improved cyrillics (bgo#706358).
  + Improved outlines and spacing (bgo#703115).
  + Missing romanian accent glyphs (bgo#705004).
  + Uppercase U shape improvements (bgo#702955).
* Fri Sep 20 2013 toms@opensuse.org
- Fixed bnc#827785: Cantarell font packaged into wrong folder
* Fri Aug 23 2013 zaitor@opensuse.org
- Update to version 0.0.14:
  + Large improvement to shapes of latin and extended latin glyphs.
  + Improvements to the numeral shapes.
  + Greatly improved horizontal metrics of regular weight.
  + Corrected maths.
  + Corrected outlines & metrics of Cyrillics.
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 0.0.13:
  + Many l/rbearking tweaks.
  + Extra symbols for Shell (bgo#657957).
  + Balanced shape for s and S.
  + Balanced shape for 6 and 9.
  + Balanced 2 and 3.
  + Improved hints.
  + OT anchors for accents.
  + Contrast tweaks to bold (b, B, e).
* Sun Dec 23 2012 zaitor@opensuse.org
- Update to version 0.0.12:
  + Improved ligatures.
  + Improve and add missing cyrillics. (bgo#689220)
  + Advanced typo glyphs. (bgo#689184)
* Fri Nov 16 2012 dimstar@opensuse.org
- Update to version 0.0.11:
  + Use ligature lookup tables.
  + Make digits monospaced for bold.
* Mon Oct  8 2012 pgajdos@suse.com
- use %%files_fontsconf_availdir and %%files_fontsconf_file macros
* Tue Oct  2 2012 pgajdos@suse.com
- install avail configuration into /usr/share/%%{name}/conf.avail
  and use %%link_avail_to_system_fontsconf macro for linking it into
  /etc/fonts/conf.d (fontconfig 2.10 doesn't use /etc/fonts/conf.avail)
* Tue Sep 25 2012 zaitor@opensuse.org
- Update to version 0.0.10.1:
  + build related fixes.
* Fri Sep 14 2012 vuntz@opensuse.org
- Update to version 0.0.10:
  + Generate OTF from SFDs automatically
  + Install to appropriate system directories
  + Fix cyrillic metrics
  + Improve EE diacritics
* Wed Jul  4 2012 pgajdos@suse.cz
- amend spec file to reflect new font packaging scheme
  (see openFATE#313536);
* Mon Jun 11 2012 dimstar@opensuse.org
- Update to version 0.0.9:
  + initial support for Cyrillic
  + uppercase Greek
* Thu May 17 2012 pgajdos@suse.com
- call spec-cleaner
* Sat Apr  7 2012 toms@opensuse.org
- Added xz to the list of BuildRequire-ments
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 0.0.8:
  + accented l (bgo#665433)
  + extrema & node fixes
  + build related fixes
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 0.0.7:
  + ON/OFF glyphs (bgo#643120)
  + combining circumflex metrics (bgo#637066)
  + ] hinting (bgo#652834)
  + bold: 'a','e','n','s' and 'c' hints.
  + black circle a circle (bgo#660442)
  + bold: sync accented characters with base glyph.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 0.0.6:
  + bold l
  + fix umlaut positions (bgo#646222)
  + README fixes
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 0.0.5:
  + improved password entry glyph
  + improved hyphen by making narrower
  + improved licensing and FONTLOG metadata
  + improved vertical metrics
- Changes from version 0.0.4:
  + improved hints on numerals and bold letters
  + improved metrics
* Thu Mar 24 2011 fcrozat@novell.com
- Add fontconfig BuildRequires for directory ownership.
* Tue Feb 22 2011 fcrozat@novell.com
- Update to version 0.0.3:
  + create the tarball from the actual git master
- Changes from version 0.0.2:
  + improved hints, hinting related metrics
  + added black circle glyph for password entries
  + increased size of '^'
  + fixed the fontconfig script not to override the global default
- Remove call to autogen.sh since we don't use a git tarball
  anymore.
* Mon Jan 17 2011 fcrozat@novell.com
- Fix fontconfig file path (/etc/fontconfig/conf.avail instead of
  /usr/share/fontconfig/conf.avail) by setting configdir in
  %%make_install, and set cantarell as default font by linking it in
  /etc/fontconfig/conf.d.
* Wed Dec 15 2010 vuntz@opensuse.org
- Initial package (from git as of 2010-12-15).
